@@ -239,9 +239,9 @@ CSG_3DView_Panel::CSG_3DView_Panel(wxWindow *pParent, CSG_Grid *pDrape)
 	//-----------------------------------------------------
 	if( (m_pDrape = pDrape) != NULL )
 	{
-		m_Parameters.Add_Node("", "MAP", _TL("Map Draping"), _TL(""));
-		m_Parameters.Add_Bool("MAP", "MAP_DRAPE", _TL("Map Draping"), _TL(""), true);
-		m_Parameters.Add_Grid_Resampling("MAP", "MAP_DRAPE_MODE", _TL("Map Drape Resampling"), _TL(""), CSG_Grid_Resampling::Interpolations, CSG_Grid_Resampling::NearestNeighbour);
+		m_Parameters.Add_Node           (""   , "MAP"           , _TL("Map Draping"), _TL(""));
+		m_Parameters.Add_Bool           ("MAP", "MAP_DRAPE"     , _TL("Drape"      ), _TL(""), true);
+		m_Parameters.Add_Grid_Resampling("MAP", "MAP_DRAPE_MODE", _TL("Resampling" ), _TL(""), CSG_Grid_Resampling::Interpolations, CSG_Grid_Resampling::NearestNeighbour);
 	}
 
 	//-----------------------------------------------------
@@ -354,7 +354,7 @@ bool CSG_3DView_Panel::Update_Parameters(bool bSave)
 
 		if( m_Parameters("MAP_DRAPE_MODE") )
 		{
-			m_Parameters["MAP_DRAPE_MODE"].Set_Value((int)m_Drape_Mode);
+			m_Parameters["MAP_DRAPE_MODE"].Set_Value(m_Drape_Mode);
 		}
 	}
 
@@ -393,13 +393,9 @@ bool CSG_3DView_Panel::Update_Parameters(bool bSave)
 		m_Label_Res   = m_Parameters["LABEL_RES"  ].asInt   ();
 		m_Label_Scale = m_Parameters["LABEL_SCALE"].asDouble();
 
-		switch( m_Parameters("MAP_DRAPE_MODE") ? m_Parameters["MAP_DRAPE_MODE"].asInt() : 0 )
-		{
-		default: m_Drape_Mode = CSG_Grid_Resampling::NearestNeighbour; break;
-		case  1: m_Drape_Mode = CSG_Grid_Resampling::Bilinear        ; break;
-		case  2: m_Drape_Mode = CSG_Grid_Resampling::Bicubic_1   ; break;
-		case  3: m_Drape_Mode = CSG_Grid_Resampling::Bicubic_2         ; break;
-		}
+		m_Drape_Mode  = m_Parameters("MAP_DRAPE_MODE")
+		              ? m_Parameters["MAP_DRAPE_MODE"].asGrid_Resampling()
+		              : CSG_Grid_Resampling::NearestNeighbour;
 	}
 
 	return( true );
